botwrapper

package
v0.0.0-...-1b8ee3a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 20, 2020 License: BSD-3-Clause Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetKBChat

func GetKBChat(keybaseHomeDir, keybasePaperKey, keybaseUsername string, keybaseTimeout time.Duration) (*kbchat.API, error)

Get a running instance of the keybase chat API. Will use the supplied credentials if necessary. If possible, it is preferred to reference the `GetKBChat` method in the `bot` package instead

Types

This section is empty.

Jump to