Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetKBChat ¶
func GetKBChat(keybaseHomeDir, keybasePaperKey, keybaseUsername string, keybaseTimeout time.Duration) (*kbchat.API, error)
Get a running instance of the keybase chat API. Will use the supplied credentials if necessary. If possible, it is preferred to reference the `GetKBChat` method in the `bot` package instead
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.